# Scheinfirmen Österreich — Statistik

> Stand: 2026-02-16T10:58:18 | Gesamt: 1276 | Tracking seit: 2026-02-10

## Neueste Scheinfirmen (letzte 30 Tage)

| Name | UID | Anschrift |
|------|-----|-----------|
| Ahmet Bulduk GmbH | ATU15647405 | 1110 Wien, Am Kanal 27 |
| DEMETER Monika Sara | ATU82203857 | 1200 Wien, Klosterneuburger Straße 28 |
| DUGMONICS Sandorne |  | 1200 Wien, Salzachstraße 1 |
| Talocci M. e.U. | ATU82520069 | 1190 Wien, Hackhofergasse 1 |

*4 Einträge hinzugefügt.*

## Wöchentliche Änderungen

| Woche | Datum | Zugänge | Abgänge | Gesamt |
|-------|-------|---------|---------|--------|
| 2026-W07 | Feb 9 | *1274 (initial)* | — | 1274 |
